ByteAddr

Struct ByteAddr 

pub struct ByteAddr(pub u32);
A memory address expressed in bytes

Tuple Fields

0: u32

Implementations

Source

impl ByteAddr

pub const fn waddr(self) -> WordAddr

Convert to a WordAddr

If the address is not aligned to a word boundary, this will return the highest aligned address smaller than the input address.

pub const fn page_idx(&self) -> u32

Gives the Page containing this memory address

pub const fn page_subaddr(&self) -> ByteAddr

The subaddress of this address relative to its containing Page

The number of bytes this address is beyond the first byte of the page which contains it.

pub fn waddr_aligned(self) -> Option<WordAddr>

Convert to a WordAddr if aligned

If the address is aligned to a word boundary, this will return the WordAddr for this memory location. If it is not aligned, it returns None.

pub const fn is_aligned(&self) -> bool

Reports if the address is aligned

Returns true if the address is aligned to a word boundary, otherwise returns false

pub const fn is_null(&self) -> bool

Reports if the address is null

The address 0x00000000 is null and will return true, for all others returns false.

pub const fn checked_add(self, rhs: u32) -> Option<Self>

Add an offset to an address, returning None on overflow.

pub const fn saturating_add(self, rhs: u32) -> Self

Add an offset to an address, saturating on overflow.

pub const fn wrapping_add(self, rhs: u32) -> Self

Add an offset to an address

This will wrap on overflow, e.g. 0xFFFFFFFF + 0x00000001 is 0x00000000.

pub const fn subaddr(&self) -> u32

The subaddress of this address relative to its containing word

The number of bytes this address is beyond the previous aligned address. So for example an aligned address will have a subaddress of 0, while the address 0x00003001 will have subaddress 1.