WordAddr

Struct WordAddr 

pub struct WordAddr(pub u32);
A memory address expressed in words

Only capable of representing aligned addresses, as adjacent WordAddrs are a word apart.

Tuple Fields

0: u32

Implementations

Source

impl WordAddr

pub const fn baddr(self) -> ByteAddr

Convert to a ByteAddr

pub const fn page_idx(&self) -> u32

Gives the crate::image::Page containing this memory address

pub const fn page_subaddr(&self) -> WordAddr

The subaddress of this address relative to its containing crate::image::Page

The number of words this address is beyond the first word of the page which contains it.

pub const fn inc(&mut self)

Increments this address to the next word

This increments the address without returning any value.

pub const fn postfix_inc(&mut self) -> Self

Increments this address to the next word and returns its previous value

This is a postfixing increment, analogous to addr++ in C; the value this evaluates to is the value prior to the increment.

pub const fn is_null(&self) -> bool

Reports if the address is null

The address 0x00000000 is null and will return true, for all others returns false.